#
# spec file for package composefs
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define         sover 1
%if 0%{?suse_version} >= 1600
%define         pythons python3
%else
%define         pythons python311
%endif
Name:           composefs
Version:        1.0.8
Release:        3.3
Summary:        The reliability of disk images, the flexibility of files
License:        Apache-2.0 OR GPL-2.0-or-later
URL:            https://github.com/containers/composefs
Source0:        %{url}/archive/v%{version}.tar.gz#/%{name}-%{version}.tar.gz
Patch0:         001-enable-experimental-tools.patch
Patch1:         002-fix-leap-tests.patch
BuildRequires:  %{pythons}-base
BuildRequires:  go-md2man
BuildRequires:  meson
BuildRequires:  pkgconfig(fuse3) >= 3.10.0
BuildRequires:  pkgconfig(libcrypto)

%description
Tools to handle creating and mounting composefs images. The composefs
project combines several underlying Linux features to provide a very
flexible mechanism to support read-only mountable filesystem trees,
stacking on top of an underlying "lower" Linux filesystem.

%package -n     lib%{name}%{sover}
Summary:        Libraries for %{name}

%description -n lib%{name}%{sover}
Library files for %{name}.

%package        devel
Summary:        Devel files for %{name}
Requires:       %{name} = %{version}
Requires:       lib%{name}%{sover} = %{version}

%description devel
Devel files for %{name}.

%package experimental
Summary:        This package contains all things experimental for %{name}

%description experimental
%{summary}.

%prep
%autosetup -N
%patch -P0 -p1
%if 0%{?suse_version} < 1600
%patch -P1 -p1
%endif

%build
%meson \
  -Dfuse=enabled \
  -Dman=enabled
%meson_build

%install
%meson_install
rm -rf %{buildroot}%{_libdir}/libcomposefs.{a,la}

%ifnarch s390x
%check
%meson_test
%endif

%ldconfig_scriptlets -n lib%{name}%{sover}

%files
%license COPYING COPYING.GPL-2.0-only COPYING.GPL-2.0-or-later COPYING.LGPL-2.1-or-later LICENSE.Apache-2.0
%doc README.md
%{_bindir}/mk%{name}
%{_bindir}/%{name}-info
%{_sbindir}/mount.%{name}
%{_mandir}/man?/%{name}-{info,dump}.?%{?ext_man}
%{_mandir}/man?/mk%{name}.?%{?ext_man}
%{_mandir}/man?/mount.%{name}.?%{?ext_man}

%files devel
%{_includedir}/lib%{name}
%{_libdir}/lib%{name}.so
%{_libdir}/pkgconfig/%{name}.pc

%files experimental
%{_bindir}/%{name}-dump
%{_bindir}/%{name}-fuse

%files -n lib%{name}%{sover}
%{_libdir}/lib%{name}.so.%{sover}*

%changelog
* Wed Feb 19 2025 Richard Rahl <rrahl0@opensuse.org>
- create an experimental package for things which are not yet stable
  * add patch 001-enable-experimental-tools.patch
- BR libcrypto rather than openssl directly
- fix leap builds by fixing the shebang (we need the newer python311 stack
  * add patch 002-fix-leap-tests.patch
* Sun Jan  5 2025 Richard Rahl <rrahl0@opensuse.org>
- for some reason s390x times out on verifying checksums in the tests,
  let's disable it for now
* Fri Jan  3 2025 Richard Rahl <rrahl0@opensuse.org>
- update to 1.0.8:
  * Add Containers Code of Conduct
  * rust: drop all Rust code from this repository
  * lib: Add lcfs_fd_measure_fsverity
  * Do not enable man page generation when it is disabled.
  * writer: Reject empty xattr names
  * writer: Fix return value of lcfs_node_unset_xattr
  * mount: Support EROFS file-backed mounts
  * mkcomposefs: Fix error message
* Sun Dec 29 2024 Richard Rahl <rrahl0@opensuse.org>
- require the main package for the devel package
* Sat Dec 14 2024 Richard Rahl <rrahl0@opensuse.org>
- update to 1.0.7:
  * Relicense most code under GPL-2.0-or-later OR Apache-2.0
  * mkcomposefs: make it cpuset aware
  * README.md: Add a "tagline"
  * mkcomposefs: Document external sandboxing
  * meson.build: raise used C standard to C11
  * libcomposefs: include linux/limits.h to satisfy usage of XATTR_NAME_MAX
  * tests: Fix should-fail-self-hardlink to conform to latest syntax
  * Fix clang warnings
  * Add a libcomposefs-internal
  * internal: Rewrite byteswapping macros
  * tests: Add a flow for integration test with fsverity enabled
  * README.md: Link to community forums
  * Add a CONTRIBUTING.md
  * MAINTAINERS.md: New file
  * writer: Add O_DIRECTORY
  * writer: Use blocksize constant
  * Fixed typos in README.md
  * lib: Add expansion comments to header
- add tests
* Thu Oct  3 2024 Richard Rahl <rrahl0@opensuse.org>
- update to 1.0.6:
  * fix rust bindings
  * fix a potential CVE
  * Autotools build system dropped
  * mkcomposefs: Process last content in dumpfile without newline
  * dump: Support --filter
  * lib: Bail on xattr names > XATTR_NAME_MAX
  * lib: Verify mode values
  * Reject an empty name
  * Two more testing improvements
  * More validation
  * rust/dumpfile: Minor optimization for unescape_to_path_canonical
  * rust: Attempt to fix build on docs.rs
  * rust: Add wrapping for composefs-info dump
  * Various fixes to the fsverity part of test-units.sh
  * Replace custom clang-format bits with stock meson targets
  * Add 64bit rdev APIs
  * libcomposefs: detect short erofs files
  * rust: Accept 64 bit values for rdev
  * A few cleanups around symlinks
  * tests: Move sha verification after other checks
  * dumpfile: Add some test code to convert to tar
  * mkcomposefs: Add a hidden CFS_PARSE_STRICT
  * Results from running honggfuzz, plus some more manual auditing
  * lib: Move validation out of lcfs_node_add_child()
  * writer: Clarifications around our usage of EROFS_NULL_ADDR
- fix licensing
- rename libcomposefs-devel to composefs-devel, as this is the opensuse way
* Wed Sep 11 2024 Richard Rahl <rrahl0@opensuse.org>
- update to 1.0.5:
  * test: use correct composefs-info binary
  * rust: Some doc and misc tweaks
  * test: remove hardcoded /tmp
  * rust: Add mandatory description field, other misc changes
  * composefs-core: Drop incorrect include
  * rust: Two minor patches
  * composefs-info: specify locale to isgraph/isprint
  * Add meson as an alternative to autotools
  * info: Add missing terminator for longopts
  * mount: Consistently use composefs as source
  * meson.build: Allow use as a meson subproject
  * mkcompose: report close() errors
  * libcomposefs: do not override errno
  * libcomposefs: drop using "ro" option
  * Minor rust lints
  * Verify payload length early on
- switch to meson buildsystem
- switch (permanently?) to tags not releases, as they forgot to add
  meson build files in release files
* Wed Jul 17 2024 Joshua Smith <smolsheep@opensuse.org>
- Initial package for bootc on openSUSE.
